@@ -19,13 +19,26 @@ def instrument():
             app_name = flask.current_app.name
 
             dt_headers = None
+            dt_header = flask.request.headers.get("X-Dynatrace")
             if os.environ.get("AUTODYNATRACE_CAPTURE_HEADERS", False):
                 dt_headers = dict(flask.request.headers)
-            wappinfo = sdk.create_web_application_info("{}".format(host), "Flask ({})".format(app_name), "/")
+
+            virtual_host = os.environ.get("AUTODYNATRACE_VIRTUAL_HOST", "{}".format(host))
+            app_name = os.environ.get("AUTODYNATRACE_APPLICATION_ID", "Flask ({})".format(app_name))
+            context_root = os.environ.get("AUTODYNATRACE_CONTEXT_ROOT", "/")
+
+            wappinfo = sdk.create_web_application_info(virtual_host, app_name, context_root)
 
         except Exception as e:
             logger.debug("dynatrace - could not instrument: {}".format(e))
             return wrapped(*args, **kwargs)
-        with sdk.trace_incoming_web_request(wappinfo, url, method, headers=dt_headers):
-            logger.debug("dynatrace - full_dispatch_request_dynatrace: {}".format(url))
+
+        try:
+            with wappinfo:
+                logger.debug("Tracing with header: {}".format(dt_header))
+                with sdk.trace_incoming_web_request(wappinfo, url, method, headers=dt_headers, str_tag=dt_header):
+                    logger.debug("dynatrace - full_dispatch_request_dynatrace: {}".format(url))
+                    return wrapped(*args, **kwargs)
+        except Exception as e:
+            logger.debug("dynatrace - could not create tracer: {}".format(e))
             return wrapped(*args, **kwargs)
